horizon-jpl 0.1.3
==================
This Python API, is an effort towards opening NASA's PDS data sets to the public with a focus on 
ease of access. Thus creating, NASA's JPL Horizons On-Line Ephemeris System API

Download the package from: https://pypi.python.org/pypi/HorizonJPL


Background
------------------------------
From http://en.wikipedia.org/wiki/Ephemeris:
```
For scientific uses, a modern planetary ephemeris comprises software that generates positions of planets and often of 
their satellites, asteroids, or comets, at virtually any time desired by the user.
```

API Documentation
------------------------------
https://docs.google.com/document/d/1g9q3ln9LVAATOZ15986HLTCaqcAj_Jd8e_jOGS3YWrE/pub

Resources
------------------------------

Planetary Data System: http://pds.nasa.gov/

Jet Propulsion Labs: http://www.jpl.nasa.gov/

HORIZON User Manual: http://ssd.jpl.nasa.gov/?horizons_doc


Contributors
------------------------------
```
Matthew Mihok (@mattmattmatt)
Dexter Jagula (@djagula)
Siddarth Kalra (@SiddarthKalra)
Tiago Moreira (@Kamots)
```
